@ECHO OFF
REM --------------------------------------------------------------------
REM MS-DOS batch file to generate a 2-D representation of the Laguerr
REM random medium and to calculate first arrival travel times
REM
REM The propagation velocities are similar to the 2-D representation of
REM the Laguerr random medium displayed in Figure 8 of paper
REM     Klimes, L. (1997): Correlation functions of random media.
REM         In: Seismic Waves in Complex 3-D Structures, Report 6.
REM         Department of Geophysics, Charles University, Prague,
REM         pp.25-40,
REM but the Gaussian corrrelation length is twice enlarged to aG=0.010.
REM
REM Input data files:
REM     ran-grd.h: grid dimensions, medium parameters, most numerical
REM         and plotting parameters,
REM     ran-src.dat: hypocentral coordinates,
REM     ran-net.dat: main input data for the NET program.
REM Output data files:
REM     ran-vel.out: propagation velocities on grid 501*501,
REM     ran-tt.out: first arrival travel times on grid 501*501,
REM     ran-p1.out, ran-p1.out: slowness-vector components,
REM PostScript figures are in files
REM     ran-vel.ps: propagation velocities on grid 501*501,
REM     ran-tt.ps: first arrival travel times on grid 501*501,
REM     ran-dir.ps: directions of propagation on grid 501*501,
REM --------------------------------------------------------------------
REM Generating a representation of the random medium :
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ECHO 'ran-grd.h' ' ' 'ran-vel.out' 1* -13 /|grdran2d
IF ERRORLEVEL 1 PAUSE
REM
REM Plotting the representation of the random medium :
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ECHO 'ran-grd.h' ' ' 'ran-vel.out' 'ran-vel.ps' /|grdps
IF ERRORLEVEL 1 PAUSE
REM
REM Calculating first-arrival travel times:
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ECHO 'ran-net.dat' /|net
IF ERRORLEVEL 1 PAUSE
REM Plotting first-arrival travel times:
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ECHO # Colours to plot wavefronts (data for GRDPS):  >ran-grd.tmp
ECHO   VCIRC=0.050  VREF=0.0  CREF=.166667          >>ran-grd.tmp
ECHO 'ran-grd.h' 'ran-grd.tmp' 'ran-tt.out' 'ran-tt.ps' /|grdps
IF ERRORLEVEL 1 PAUSE
ECHO.                                               >>ran-grd.tmp
REM Plotting directions of propagation:
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ECHO # Colours to plot directions of propagation:   >>ran-grd.tmp
ECHO   VCIRC=6.283185  VREF=0.000  CREF=.166667     >>ran-grd.tmp
ECHO 'ran-grd.h' 'atan2' 'ran-p1.out' 'ran-p2.out' 'ran-dir.tmp'/|grdcal
IF ERRORLEVEL 1 PAUSE
ECHO 'ran-grd.h' 'ran-grd.tmp' 'ran-dir.tmp' 'ran-dir.ps' /|grdps
IF ERRORLEVEL 1 PAUSE
REM --------------------------------------------------------------------
GOTO :END
REM Checking the accuracy of travel times (disabled by default):
REM ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
REM Input data files:
REM     ran-grd2.h: dimensions of denser grid for the check of accuracy,
REM     ran-net2.dat: corresponding main input data for the NET program.
REM Output data files:
REM     ran-tt2.out: first arrival travel times on grid 'ran-grd.h',
REM         calculated on grid 'ran-grd2.h',
REM     ran-err.out: absolute value of travel-time differences between
REM         'ran-tt.out' and 'ran-tt2.out',
REM     ran-err.out: relative travel-time differences between
REM         'ran-tt.out' and 'ran-tt2.out'.
REM PostScript figures are in files
REM     ran-err.ps: absolute diferences of first arrival travel times,
REM     ran-rel.ps: relative diferences of first arrival travel times.
REM
REM     Colour:   Absolute  Relative
REM               errors:   errors:
REM       yellow    0.000     0.000
REM       green     0.001     0.002
REM       cyan      0.002     0.004
REM       blue      0.003     0.006
REM       magenta   0.004     0.008
REM       red       0.005     0.010
REM --------------------------------------------------------------------
ECHO 'ran-grd.h' 'ran-grd2.h' 'ran-vel.out' 'ran-vel.tmp' /|grdnew
IF ERRORLEVEL 1 PAUSE
ECHO 'ran-net2.dat' /|net
IF ERRORLEVEL 1 PAUSE
ECHO 'ran-grd2.h' 'ran-grd.h' 'ran-tt.tmp' 'ran-tt2.out' /|grdnew
IF ERRORLEVEL 1 PAUSE
ECHO.                                               >>ran-grd.tmp
ECHO # Colours to plot absolute travel-time errors: >>ran-grd.tmp
ECHO   VCIRC=0.006  VREF=0.000  CREF=.166667        >>ran-grd.tmp
ECHO 'ran-grd.h' 'absdif' 'ran-tt.out' 'ran-tt2.out' 'ran-err.out'/|grdcal
IF ERRORLEVEL 1 PAUSE
ECHO 'ran-grd.h' 'ran-grd.tmp' 'ran-err.out' 'ran-err.ps' /|grdps
IF ERRORLEVEL 1 PAUSE
ECHO.                                               >>ran-grd.tmp
ECHO # Colours to plot relative travel-time errors: >>ran-grd.tmp
ECHO   VCIRC=0.012  VREF=0.000  CREF=.166667        >>ran-grd.tmp
ECHO 'ran-grd.h' 'reldif' 'ran-tt.out' 'ran-tt2.out' 'ran-rel.out'/|grdcal
IF ERRORLEVEL 1 PAUSE
ECHO 'ran-grd.h' 'ran-grd.tmp' 'ran-rel.out' 'ran-rel.ps' /|grdps
IF ERRORLEVEL 1 PAUSE
REM --------------------------------------------------------------------
:END
